// Variable Section

// Main Section
var script = {
    name: 'CarouselDiagonal',
    props: {
        screens: {},
        sideWidth: { default: function (){ return 5 } },
        color: { default: function (){ return '#AA0F2F' } },
        textPrev: { default: function (){ return 'PREV' } },
        muted: {},
    },
    watch: {
        muted: function (val) {
            this.muted_ = val;
        },
    },
    data: function () {
        return {
            video: null,
            indexHover: null,
            indexClick: null,
            muted_: true
        }
    },
    created: function created() {},
    methods: {
        indexScreen: function indexScreen (screen) {
            if(!screen) { return }
            return this.screens.indexOf(screen)
        },
        refScreen: function refScreen (screen) {
            if(!screen) { return }
            return 'screen' + this.indexScreen(screen)
        },
        playVideo: function playVideo(screenPlay) {
            for (var i=0; i<this.countScreen; i++) {
                var screenIth = this.screens[i];
                if (this.refScreen(screenIth) === this.refScreen(screenPlay)) {
                    this.$refs[this.refScreen(screenIth)][0].play();
                } else {
                    this.$refs[this.refScreen(screenIth)][0].pause();
                }
            }
        },
        setHoverIndex: function setHoverIndex (screen) {
            this.indexHover = this.indexScreen(screen);
            this.playVideo(screen);
        },
        resetHoverIndex: function resetHoverIndex () {
            if (!this.indexClick) {
                this.indexHover = null;
            }
        },
        setClickIndex: function setClickIndex (screen) {
            this.indexClick = this.indexScreen(screen);
            this.playVideo(screen);
        },
        resetClickIndex: function resetClickIndex () {
            this.indexClick = null;
        },
        leftTitle: function leftTitle (screen) {
            var index = this.indexScreen(screen);

            // Check index
            if (index === 0) {
                return this.widthScreen/4 + this.sideWidth/2
            } else if (index === this.screens.length-1) {
                return 100 - this.widthScreen/4 - this.sideWidth/2
            } else {
                return index * this.widthScreen + this.sideWidth
            }
        },
        zIndexScreen: function zIndexScreen (screen) {
            return this.indexScreen(screen) + 1
        },
        clipPathScreen: function clipPathScreen (screen) {
            var result;
            var index = this.indexScreen(screen);
            if (index === 0) {
                return 'polygon(0% 0, 100% 0, 100% 100%, 0% 100%)'
            }
            var top = ((index-1) * this.widthScreen + this.sideWidth);
            var bottom = (index * this.widthScreen + this.sideWidth);

            if (this.indexClick !== null && this.indexClick >= 0) {
                if (index === this.indexHover) {
                    top = 0;
                    bottom = 0;
                } else if (index > this.indexHover) {
                    top = 100;
                    bottom = 100;
                }

            }
            if (this.indexHover !== null && this.indexHover >= 0) {
                if (index === this.indexHover) {
                    top -= this.sideWidth;
                    bottom -= this.sideWidth;
                } else if (index === this.indexHover+1) {
                    top += this.sideWidth;
                    bottom += this.sideWidth;
                }
            }
            // eslint-disable-next-line prefer-const
            result = 'polygon(' + top + '% 0, 100% 0, 100% 100%, ' + bottom +'% 100%)';
            return result
        },
        openLink: function openLink (screen) {
            if (screen.link) {
                window.open(screen.link, '_blank');
            }
        },
        toggleMute: function toggleMute () {
            this.muted_ = !this.muted_;
        }
    },
    computed: {
        countScreen: function countScreen () {
            return this.screens.length
        },
        widthScreen: function widthScreen () {
            var sideWidth = 5;
            if( this.sideWidth>0 && this.sideWidth<100 ) {
                sideWidth = this.sideWidth;
            }
            return (100 - sideWidth*2) / (this.screens.length-1)
        },
        screen: function screen () {
            if(this.indexClick!=null) {
                return this.screens[this.indexClick]
            } else {
                return null
            }
        },
        isPartialSound: function isPartialSound () {
            var result = false;
            for (var i=0; i<this.countScreen; i++){
                var screen = this.screens[i];
                if(screen.isSound) {
                    result = true;
                }
            }
            return result
        }
    }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    var options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    var hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            var originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            var existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

var isOldIE = typeof navigator !== 'undefined' &&
    /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
function createInjector(context) {
    return function (id, style) { return addStyle(id, style); };
}
var HEAD;
var styles = {};
function addStyle(id, css) {
    var group = isOldIE ? css.media || 'default' : id;
    var style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
    if (!style.ids.has(id)) {
        style.ids.add(id);
        var code = css.source;
        if (css.map) {
            // https://developer.chrome.com/devtools/docs/javascript-debugging
            // this makes source maps inside style tags work properly in Chrome
            code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
            // http://stackoverflow.com/a/26603875
            code +=
                '\n/*# sourceMappingURL=data:application/json;base64,' +
                    btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                    ' */';
        }
        if (!style.element) {
            style.element = document.createElement('style');
            style.element.type = 'text/css';
            if (css.media)
                { style.element.setAttribute('media', css.media); }
            if (HEAD === undefined) {
                HEAD = document.head || document.getElementsByTagName('head')[0];
            }
            HEAD.appendChild(style.element);
        }
        if ('styleSheet' in style.element) {
            style.styles.push(code);
            style.element.styleSheet.cssText = style.styles
                .filter(Boolean)
                .join('\n');
        }
        else {
            var index = style.ids.size - 1;
            var textNode = document.createTextNode(code);
            var nodes = style.element.childNodes;
            if (nodes[index])
                { style.element.removeChild(nodes[index]); }
            if (nodes.length)
                { style.element.insertBefore(textNode, nodes[index]); }
            else
                { style.element.appendChild(textNode); }
        }
    }
}

/* script */
var __vue_script__ = script;

/* template */
var __vue_render__ = function() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c(
    "div",
    {
      class: { clicked: _vm.indexClick !== null },
      attrs: { id: "CarouselDiagonal" },
      on: { mouseleave: _vm.resetHoverIndex }
    },
    [
      _vm._l(_vm.screens, function(screen, index) {
        return _c(
          "div",
          {
            key: index,
            staticClass: "screen",
            style: {
              "clip-path": _vm.clipPathScreen(screen),
              "z-index": _vm.zIndexScreen(screen)
            },
            on: {
              mouseover: function($event) {
                return _vm.setHoverIndex(screen)
              },
              click: function($event) {
                return _vm.setClickIndex(screen)
              }
            }
          },
          [
            screen.video
              ? _c(
                  "video",
                  {
                    ref: _vm.refScreen(screen),
                    refInFor: true,
                    staticClass: "b-img",
                    attrs: { loop: "" },
                    domProps: { muted: _vm.muted_ }
                  },
                  [
                    _c("source", {
                      attrs: { src: screen.video, type: "video/mp4" }
                    })
                  ]
                )
              : _vm._e(),
            _vm._v(" "),
            screen.image
              ? _c("img", {
                  ref: _vm.refScreen(screen),
                  refInFor: true,
                  staticClass: "b-img",
                  attrs: { src: screen.image }
                })
              : _vm._e(),
            _vm._v(" "),
            _c(
              "div",
              {
                staticClass: "title",
                style: {
                  left: _vm.leftTitle(screen) + "%"
                }
              },
              [
                _c("div", { staticClass: "title1" }, [
                  _vm._v(_vm._s(screen.subtitle))
                ]),
                _c("br"),
                _vm._v(" "),
                _c("div", { staticClass: "title2" }, [
                  _vm._v(_vm._s(screen.title))
                ])
              ]
            )
          ]
        )
      }),
      _vm._v(" "),
      _c("transition", { attrs: { name: "fade" } }, [
        _vm.indexClick !== null
          ? _c(
              "button",
              { staticClass: "reset", on: { click: _vm.resetClickIndex } },
              [
                _c(
                  "svg",
                  {
                    attrs: {
                      width: "11px",
                      height: "20px",
                      viewBox: "0 0 11 20",
                      version: "1.1",
                      xmlns: "http://www.w3.org/2000/svg",
                      "xmlns:xlink": "http://www.w3.org/1999/xlink"
                    }
                  },
                  [
                    _c(
                      "g",
                      {
                        attrs: {
                          id: "Icons",
                          stroke: "none",
                          "stroke-width": "1",
                          fill: "none",
                          "fill-rule": "evenodd"
                        }
                      },
                      [
                        _c(
                          "g",
                          {
                            attrs: {
                              id: "Rounded",
                              transform: "translate(-548.000000, -3434.000000)"
                            }
                          },
                          [
                            _c(
                              "g",
                              {
                                attrs: {
                                  id: "Navigation",
                                  transform:
                                    "translate(100.000000, 3378.000000)"
                                }
                              },
                              [
                                _c(
                                  "g",
                                  {
                                    attrs: {
                                      id:
                                        "-Round-/-Navigation-/-arrow_back_ios",
                                      transform:
                                        "translate(442.000000, 54.000000)"
                                    }
                                  },
                                  [
                                    _c("g", [
                                      _c("polygon", {
                                        attrs: {
                                          id: "Path",
                                          opacity: "0.87",
                                          points: "0 0 24 0 24 24 0 24"
                                        }
                                      }),
                                      _vm._v(" "),
                                      _c("path", {
                                        attrs: {
                                          d:
                                            "M16.62,2.99 C16.13,2.5 15.34,2.5 14.85,2.99 L6.54,11.3 C6.15,11.69 6.15,12.32 6.54,12.71 L14.85,21.02 C15.34,21.51 16.13,21.51 16.62,21.02 C17.11,20.53 17.11,19.74 16.62,19.25 L9.38,12 L16.63,4.75 C17.11,4.27 17.11,3.47 16.62,2.99 Z",
                                          id: "🔹-Icon-Color",
                                          fill: "#FFFFFF"
                                        }
                                      })
                                    ])
                                  ]
                                )
                              ]
                            )
                          ]
                        )
                      ]
                    )
                  ]
                ),
                _vm._v(" "),
                _c("span", [_vm._v(_vm._s(_vm.textPrev))])
              ]
            )
          : _vm._e()
      ]),
      _vm._v(" "),
      _vm.screen && _vm.screen.link
        ? _c("button", {
            staticClass: "link-button",
            on: {
              click: function($event) {
                return _vm.openLink(_vm.screen)
              }
            }
          })
        : _vm._e(),
      _vm._v(" "),
      !_vm.isPartialSound || (_vm.screen && _vm.screen.isSound)
        ? _vm._t("mute", [
            _c(
              "button",
              {
                staticClass: "mute",
                staticStyle: {
                  width: "40px",
                  height: "60px",
                  position: "absolute",
                  top: "10%",
                  right: "5%",
                  transition: "all 500ms",
                  opacity: "0.5",
                  "z-index": "99"
                },
                attrs: {
                  onmouseover: "style.opacity=1",
                  onmouseleave: "style.opacity=0.5"
                },
                on: { click: _vm.toggleMute }
              },
              [
                _vm.muted_
                  ? _c(
                      "svg",
                      {
                        attrs: {
                          width: "40px",
                          viewBox: "0 0 100 100",
                          fill: "none",
                          xmlns: "http://www.w3.org/2000/svg"
                        }
                      },
                      [
                        _c("path", {
                          attrs: {
                            "fill-rule": "evenodd",
                            "clip-rule": "evenodd",
                            d:
                              "M98.9154 3.41424C99.6965 2.6332 99.6965 1.36687 98.9154 0.585817C98.1344 -0.195232 96.8681 -0.195232 96.087 0.585817L49 47.6728V14.2298C49 12.5906 48.4911 10.6473 46.7155 9.82353C44.9465 9.00277 43.1326 9.85813 41.8744 10.9065L16.2692 32.5014H4.99942C2.24004 32.5014 0 34.7397 0 37.5014V61.5014C0 64.2565 2.23614 66.5014 4.99942 66.5014H16.2757L23.8541 72.8187L1.07382 95.599C0.292775 96.3801 0.292775 97.6464 1.07382 98.4274C1.85487 99.2085 3.1212 99.2085 3.90225 98.4274L26.9392 75.3905L41.8744 87.8404C43.134 88.89 44.9485 89.7439 46.7172 88.9217C48.4909 88.0971 49 86.1553 49 84.5172V53.3297L98.9154 3.41424ZM45 51.6728V14.2298C45 13.9656 44.9775 13.7655 44.9493 13.6199C44.8172 13.692 44.646 13.8042 44.4392 13.9761L44.435 13.9796L18.2894 36.0303C17.9287 36.3345 17.4719 36.5014 17 36.5014H4.99942C4.44866 36.5014 4 36.9494 4 37.5014V61.5014C4 62.0517 4.44964 62.5014 4.99942 62.5014H17C17.468 62.5014 17.9211 62.6655 18.2806 62.9652L26.6942 69.9787L45 51.6728ZM29.7793 72.5504L45 57.3297V84.5172C45 84.7814 44.9775 84.9814 44.9492 85.1269C44.8163 85.0545 44.6437 84.9413 44.435 84.7674L29.7793 72.5504ZM86.8101 22.3048C87.6391 21.5748 88.9029 21.6551 89.6329 22.4841C95.9918 29.706 99.8511 39.1887 99.8511 49.5678C99.8511 67.7551 88.0104 83.1717 71.6226 88.539C70.5729 88.8828 69.4432 88.3106 69.0994 87.2609C68.7556 86.2112 69.3278 85.0815 70.3775 84.7377C85.1706 79.8927 95.8511 65.9749 95.8511 49.5678C95.8511 40.1986 92.3713 31.6471 86.6308 25.1275C85.9008 24.2985 85.9811 23.0347 86.8101 22.3048ZM78.5882 32.6655C77.8629 31.8323 76.5996 31.7448 75.7665 32.47C74.9333 33.1952 74.8458 34.4585 75.5711 35.2917C78.9352 39.1565 80.9701 44.2024 80.9701 49.7286C80.9701 59.9671 73.9743 68.5766 64.499 71.0285C63.4296 71.3052 62.7871 72.3964 63.0638 73.4658C63.3405 74.5351 64.4317 75.1777 65.501 74.901C76.6981 72.0036 84.9701 61.8346 84.9701 49.7286C84.9701 43.2008 82.5619 37.2306 78.5882 32.6655ZM65.6336 42.7395C66.5875 42.1826 67.8122 42.5044 68.3692 43.4583C69.4063 45.2347 70 47.3018 70 49.5014C70 55.2801 65.9173 60.1007 60.4804 61.2443C59.6784 61.4131 58.8484 61.5014 58 61.5014C56.8954 61.5014 56 60.606 56 59.5014C56 58.3968 56.8954 57.5014 58 57.5014C58.5701 57.5014 59.1241 57.4421 59.657 57.33C63.2805 56.5678 66 53.3499 66 49.5014C66 48.0295 65.6043 46.656 64.9148 45.4751C64.3579 44.5212 64.6797 43.2964 65.6336 42.7395Z",
                            fill: "white"
                          }
                        })
                      ]
                    )
                  : _c(
                      "svg",
                      {
                        attrs: {
                          width: "40px",
                          height: "79",
                          viewBox: "0 0 100 79",
                          fill: "none",
                          xmlns: "http://www.w3.org/2000/svg"
                        }
                      },
                      [
                        _c("path", {
                          attrs: {
                            "fill-rule": "evenodd",
                            "clip-rule": "evenodd",
                            d:
                              "M43.5951 4.46459L43.5993 4.46113C43.775 4.31509 43.9236 4.21396 44.0428 4.14467C44.065 4.27858 44.0816 4.45432 44.0816 4.67838V73.5313C44.0816 73.7554 44.0649 73.9311 44.0427 74.0649C43.9226 73.9951 43.7727 73.893 43.5951 73.7451L17.9745 52.3878C17.615 52.0881 17.1619 51.924 16.6939 51.924H4.93821C4.42223 51.924 4 51.5018 4 50.9852V27.475C4 26.9568 4.42122 26.5363 4.93821 26.5363H16.6939C17.1658 26.5363 17.6225 26.3694 17.9833 26.0651L43.5951 4.46459ZM48.0816 4.67838C48.0816 3.06732 47.5815 1.14222 45.8201 0.32499C44.0653 -0.489182 42.2711 0.361213 41.0345 1.39157L15.9631 22.5363H4.93821C2.21261 22.5363 0 24.7472 0 27.475V50.9852C0 53.7066 2.20873 55.924 4.93821 55.924H15.9696L41.0345 76.8181C42.2724 77.8496 44.0673 78.6986 45.8218 77.8829C47.5813 77.065 48.0816 75.1413 48.0816 73.5313V4.67838ZM72.1866 1.08479C71.137 0.740628 70.0071 1.31249 69.663 2.36207C69.3188 3.41165 69.8907 4.54151 70.9403 4.88567C85.409 9.63002 95.8541 23.2454 95.8541 39.2952C95.8541 55.3493 85.4034 68.9677 70.9285 73.7085C69.8788 74.0523 69.3066 75.182 69.6504 76.2317C69.9942 77.2814 71.1238 77.8537 72.1735 77.5099C88.2431 72.2467 99.8541 57.1295 99.8541 39.2952C99.8541 21.4657 88.2494 6.35184 72.1866 1.08479ZM63.7718 16.1956C64.0501 15.1267 65.1423 14.4857 66.2112 14.764C77.1786 17.6196 85.2768 27.5879 85.2768 39.4527C85.2768 51.3307 77.1606 61.3081 66.1745 64.1509C65.1051 64.4276 64.014 63.7851 63.7372 62.7157C63.4605 61.6464 64.1031 60.5552 65.1724 60.2785C74.4368 57.8812 81.2768 49.4632 81.2768 39.4527C81.2768 29.4534 74.452 21.043 65.2033 18.635C64.1344 18.3567 63.4935 17.2645 63.7718 16.1956ZM58.8163 27.4342C57.7118 27.4342 56.8163 28.3296 56.8163 29.4342C56.8163 30.5388 57.7118 31.4342 58.8163 31.4342C59.3164 31.4342 59.8036 31.481 60.2745 31.57C63.8831 32.2517 66.6122 35.4243 66.6122 39.2301C66.6122 42.9804 63.9622 46.1163 60.4311 46.859C59.9118 46.9682 59.3719 47.026 58.8163 47.026C57.7118 47.026 56.8163 47.9215 56.8163 49.026C56.8163 50.1306 57.7118 51.026 58.8163 51.026C59.6503 51.026 60.4661 50.9392 61.2545 50.7734C66.599 49.6492 70.6122 44.9106 70.6122 39.2301C70.6122 33.4661 66.48 28.6715 61.017 27.6395C60.3026 27.5045 59.5667 27.4342 58.8163 27.4342Z",
                            fill: "white"
                          }
                        })
                      ]
                    )
              ]
            )
          ])
        : _vm._e()
    ],
    2
  )
};
var __vue_staticRenderFns__ = [];
__vue_render__._withStripped = true;

  /* style */
  var __vue_inject_styles__ = function (inject) {
    if (!inject) { return }
    inject("data-v-197bd628_0", { source: "#CarouselDiagonal {\n  position: relative;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n}\n#CarouselDiagonal .screen {\n  position: absolute;\n  top: 0;\n  left: 0;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n  overflow: hidden;\n  transition: all 1s;\n  background: #bdc3c7;\n  /* fallback for old browsers */\n  background: -webkit-linear-gradient(to right, #bdc3c7, #2c3e50);\n  /* Chrome 10-25, Safari 5.1-6 */\n  background: linear-gradient(to right, #bdc3c7, #2c3e50);\n  /* W3C, IE 10+/ Edge, Firefox 16+, Chrome 26+, Opera 12+, Safari 7+ */\n}\n#CarouselDiagonal .screen .title {\n  position: absolute;\n  top: 50%;\n  z-index: 6;\n  display: inline-block;\n  color: white;\n  transition: all 2s;\n  transform: translateX(-50%) translateY(-50%);\n}\n#CarouselDiagonal .screen .title .title1 {\n  font-size: 27px;\n  font-weight: 600;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n  float: left;\n}\n#CarouselDiagonal .screen .title .title2 {\n  font-size: 36px;\n  font-weight: 900;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n  float: left;\n}\n#CarouselDiagonal.clicked .title {\n  top: 50% !important;\n  left: 50% !important;\n  opacity: 0;\n  transform: translateX(-50%) translateY(-50%) !important;\n}\n#CarouselDiagonal .reset {\n  position: absolute;\n  bottom: 5%;\n  left: 5%;\n  z-index: 6;\n  font-size: 18px;\n  color: white;\n  background: none;\n  line-height: 20px;\n  padding: 10px;\n}\n#CarouselDiagonal .reset * {\n  float: left;\n}\n#CarouselDiagonal .reset span {\n  line-height: 20px;\n  vertical-align: middle;\n  margin-left: 12px;\n}\n#CarouselDiagonal button.mute svg {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n}\n#CarouselDiagonal .fade-enter-active, #CarouselDiagonal .fade-leave-active {\n  transition: opacity 1s;\n  opacity: 100;\n}\n#CarouselDiagonal .fade-enter, #CarouselDiagonal .fade-leave-to {\n  opacity: 0;\n}\n#CarouselDiagonal .b-img {\n  width: 100%;\n  height: 100%;\n  background-size: cover;\n  background-position: center center;\n  object-fit: cover;\n}\n#CarouselDiagonal button, #CarouselDiagonal button:focus {\n  border: none;\n  outline: none;\n  background: none;\n  cursor: pointer;\n}\n#CarouselDiagonal .link-button {\n  position: absolute;\n  width: 100%;\n  height: 50%;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n  background: none;\n  z-index: 99;\n}\n#CarouselDiagonal video::-webkit-media-controls-panel {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-play-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-start-playback-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n\n/*# sourceMappingURL=CarouselDiagonal.vue.map */", map: {"version":3,"sources":["/Users/idist/Desktop/git/library/vue-carousel-diagonal/src/components/CarouselDiagonal.vue","CarouselDiagonal.vue"],"names":[],"mappings":"AA0MA;EACA,kBAAA;EACA,cAAA;EACA,WAAA;EACA,WAAA;EACA,YAAA;ACzMA;AD0MA;EACA,kBAAA;EACA,MAAA;EACA,OAAA;EACA,cAAA;EACA,WAAA;EACA,WAAA;EACA,YAAA;EACA,gBAAA;EACA,kBAAA;EACA,mBAAA;EAAA,8BAAA;EACA,+DAAA;EAAA,+BAAA;EACA,uDAAA;EAAA,qEAAA;ACrMA;ADsMA;EACA,kBAAA;EACA,QAAA;EACA,UAAA;EACA,qBAAA;EACA,YAAA;EACA,kBAAA;EACA,4CAAA;ACpMA;ADqMA;EACA,eAAA;EACA,gBAAA;EACA,0CAAA;EACA,WAAA;ACnMA;ADqMA;EACA,eAAA;EACA,gBAAA;EACA,0CAAA;EACA,WAAA;ACnMA;ADwMA;EACA,mBAAA;EACA,oBAAA;EACA,UAAA;EACA,uDAAA;ACtMA;ADyMA;EACA,kBAAA;EACA,UAAA;EACA,QAAA;EACA,UAAA;EACA,eAAA;EACA,YAAA;EACA,gBAAA;EACA,iBAAA;EACA,aAAA;ACvMA;ADwMA;EAAA,WAAA;ACrMA;ADsMA;EACA,iBAAA;EACA,sBAAA;EACA,iBAAA;ACpMA;ADyMA;EACA,kBAAA;EACA,QAAA;EACA,SAAA;EACA,gCAAA;ACvMA;AD2MA;EACA,sBAAA;EACA,YAAA;ACzMA;AD2MA;EACA,UAAA;ACzMA;AD2MA;EACA,WAAA;EACA,YAAA;EACA,sBAAA;EACA,kCAAA;EACA,iBAAA;ACzMA;AD2MA;EACA,YAAA;EACA,aAAA;EACA,gBAAA;EACA,eAAA;ACzMA;AD4MA;EACA,kBAAA;EACA,WAAA;EACA,WAAA;EACA,QAAA;EACA,SAAA;EACA,gCAAA;EACA,gBAAA;EACA,WAAA;AC1MA;AD6MA;EAAA,wBAAA;EAAA,wBAAA;ACzMA;AD0MA;EAAA,wBAAA;EAAA,wBAAA;ACtMA;ADuMA;EAAA,wBAAA;EAAA,wBAAA;ACnMA;;AAEA,+CAA+C","file":"CarouselDiagonal.vue","sourcesContent":["<script>\n    // Variable Section\n\n    // Main Section\n    export default {\n        name: 'CarouselDiagonal',\n        props: {\n            screens: {},\n            sideWidth: { default: ()=> { return 5 } },\n            color: { default: ()=> { return '#AA0F2F' } },\n            textPrev: { default: ()=> { return 'PREV' } },\n            muted: {},\n        },\n        watch: {\n            muted: function (val) {\n                this.muted_ = val\n            },\n        },\n        data: function () {\n            return {\n                video: null,\n                indexHover: null,\n                indexClick: null,\n                muted_: true\n            }\n        },\n        created() {},\n        methods: {\n            indexScreen (screen) {\n                if(!screen) { return }\n                return this.screens.indexOf(screen)\n            },\n            refScreen (screen) {\n                if(!screen) { return }\n                return 'screen' + this.indexScreen(screen)\n            },\n            playVideo(screenPlay) {\n                for (let i=0; i<this.countScreen; i++) {\n                    const screenIth = this.screens[i]\n                    if (this.refScreen(screenIth) === this.refScreen(screenPlay)) {\n                        this.$refs[this.refScreen(screenIth)][0].play()\n                    } else {\n                        this.$refs[this.refScreen(screenIth)][0].pause()\n                    }\n                }\n            },\n            setHoverIndex (screen) {\n                this.indexHover = this.indexScreen(screen)\n                this.playVideo(screen)\n            },\n            resetHoverIndex () {\n                if (!this.indexClick) {\n                    this.indexHover = null\n                }\n            },\n            setClickIndex (screen) {\n                this.indexClick = this.indexScreen(screen)\n                this.playVideo(screen)\n            },\n            resetClickIndex () {\n                this.indexClick = null\n            },\n            leftTitle (screen) {\n                const index = this.indexScreen(screen)\n\n                // Check index\n                if (index === 0) {\n                    return this.widthScreen/4 + this.sideWidth/2\n                } else if (index === this.screens.length-1) {\n                    return 100 - this.widthScreen/4 - this.sideWidth/2\n                } else {\n                    return index * this.widthScreen + this.sideWidth\n                }\n            },\n            zIndexScreen (screen) {\n                return this.indexScreen(screen) + 1\n            },\n            clipPathScreen (screen) {\n                let result\n                const index = this.indexScreen(screen)\n                if (index === 0) {\n                    return 'polygon(0% 0, 100% 0, 100% 100%, 0% 100%)'\n                }\n                let top = ((index-1) * this.widthScreen + this.sideWidth)\n                let bottom = (index * this.widthScreen + this.sideWidth)\n\n                if (this.indexClick !== null && this.indexClick >= 0) {\n                    if (index === this.indexHover) {\n                        top = 0\n                        bottom = 0\n                    } else if (index > this.indexHover) {\n                        top = 100\n                        bottom = 100\n                    }\n\n                }\n                if (this.indexHover !== null && this.indexHover >= 0) {\n                    if (index === this.indexHover) {\n                        top -= this.sideWidth\n                        bottom -= this.sideWidth\n                    } else if (index === this.indexHover+1) {\n                        top += this.sideWidth\n                        bottom += this.sideWidth\n                    }\n                }\n                // eslint-disable-next-line prefer-const\n                result = 'polygon(' + top + '% 0, 100% 0, 100% 100%, ' + bottom +'% 100%)'\n                return result\n            },\n            openLink (screen) {\n                if (screen.link) {\n                    window.open(screen.link, '_blank')\n                }\n            },\n            toggleMute () {\n                this.muted_ = !this.muted_\n            }\n        },\n        computed: {\n            countScreen () {\n                return this.screens.length\n            },\n            widthScreen () {\n                let sideWidth = 5\n                if( this.sideWidth>0 && this.sideWidth<100 ) {\n                    sideWidth = this.sideWidth\n                }\n                return (100 - sideWidth*2) / (this.screens.length-1)\n            },\n            screen () {\n                if(this.indexClick!=null) {\n                    return this.screens[this.indexClick]\n                } else {\n                    return null\n                }\n            },\n            isPartialSound () {\n                let result = false\n                for (let i=0; i<this.countScreen; i++){\n                    let screen = this.screens[i]\n                    if(screen.isSound) {\n                        result = true\n                    }\n                }\n                return result\n            }\n        }\n    }\n</script>\n\n<template>\n    <div id=\"CarouselDiagonal\" :class=\"{ 'clicked': indexClick !== null }\" @mouseleave=\"resetHoverIndex\">\n        <!--Videos-->\n        <div v-for=\"(screen, index) in screens\"\n             :key=\"index\" class=\"screen\"\n             @mouseover=\"setHoverIndex(screen)\"\n             @click=\"setClickIndex(screen)\"\n             :style=\"{\n                'clip-path': clipPathScreen(screen),\n                'z-index': zIndexScreen(screen),\n            }\">\n            <!--Video-->\n            <video class=\"b-img\" v-if=\"screen.video\" :ref=\"refScreen(screen)\" loop :muted=\"muted_\"><source :src=\"screen.video\" type=\"video/mp4\"></video>\n            <img class=\"b-img\" v-if=\"screen.image\" :ref=\"refScreen(screen)\" :src=\"screen.image\"/>\n\n            <!--Title-->\n            <div class=\"title\" :style=\"{\n              'left': leftTitle(screen) + '%',\n            }\">\n                <div class=\"title1\">{{screen.subtitle}}</div><br/>\n                <div class=\"title2\">{{screen.title}}</div>\n            </div>\n        </div>\n\n        <!--Reset-->\n        <transition name=\"fade\">\n            <button class=\"reset\" @click=\"resetClickIndex\" v-if=\"indexClick !== null\">\n                <svg width=\"11px\" height=\"20px\" viewBox=\"0 0 11 20\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\"> <g id=\"Icons\" stroke=\"none\" stroke-width=\"1\" fill=\"none\" fill-rule=\"evenodd\"> <g id=\"Rounded\" transform=\"translate(-548.000000, -3434.000000)\"> <g id=\"Navigation\" transform=\"translate(100.000000, 3378.000000)\"> <g id=\"-Round-/-Navigation-/-arrow_back_ios\" transform=\"translate(442.000000, 54.000000)\"> <g> <polygon id=\"Path\" opacity=\"0.87\" points=\"0 0 24 0 24 24 0 24\"></polygon> <path d=\"M16.62,2.99 C16.13,2.5 15.34,2.5 14.85,2.99 L6.54,11.3 C6.15,11.69 6.15,12.32 6.54,12.71 L14.85,21.02 C15.34,21.51 16.13,21.51 16.62,21.02 C17.11,20.53 17.11,19.74 16.62,19.25 L9.38,12 L16.63,4.75 C17.11,4.27 17.11,3.47 16.62,2.99 Z\" id=\"🔹-Icon-Color\" fill=\"#FFFFFF\"></path> </g> </g> </g> </g> </g> </svg>\n                <span>{{textPrev}}</span>\n            </button>\n        </transition>\n\n        <!--Link-->\n        <button v-if=\"screen && screen.link\"\n                @click=\"openLink(screen)\"\n                class=\"link-button\"></button>\n\n        <!--Mute-->\n        <slot name=\"mute\" v-if=\"!isPartialSound || (screen && screen.isSound)\">\n            <button class=\"mute\" @click=\"toggleMute\" style=\"width: 40px; height: 60px; position: absolute; top: 10%; right: 5%; transition: all 500ms; opacity: 0.5; z-index: 99;\" onmouseover=\"style.opacity=1\" onmouseleave=\"style.opacity=0.5\">\n                <svg v-if=\"muted_\" width=\"40px\" viewBox=\"0 0 100 100\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M98.9154 3.41424C99.6965 2.6332 99.6965 1.36687 98.9154 0.585817C98.1344 -0.195232 96.8681 -0.195232 96.087 0.585817L49 47.6728V14.2298C49 12.5906 48.4911 10.6473 46.7155 9.82353C44.9465 9.00277 43.1326 9.85813 41.8744 10.9065L16.2692 32.5014H4.99942C2.24004 32.5014 0 34.7397 0 37.5014V61.5014C0 64.2565 2.23614 66.5014 4.99942 66.5014H16.2757L23.8541 72.8187L1.07382 95.599C0.292775 96.3801 0.292775 97.6464 1.07382 98.4274C1.85487 99.2085 3.1212 99.2085 3.90225 98.4274L26.9392 75.3905L41.8744 87.8404C43.134 88.89 44.9485 89.7439 46.7172 88.9217C48.4909 88.0971 49 86.1553 49 84.5172V53.3297L98.9154 3.41424ZM45 51.6728V14.2298C45 13.9656 44.9775 13.7655 44.9493 13.6199C44.8172 13.692 44.646 13.8042 44.4392 13.9761L44.435 13.9796L18.2894 36.0303C17.9287 36.3345 17.4719 36.5014 17 36.5014H4.99942C4.44866 36.5014 4 36.9494 4 37.5014V61.5014C4 62.0517 4.44964 62.5014 4.99942 62.5014H17C17.468 62.5014 17.9211 62.6655 18.2806 62.9652L26.6942 69.9787L45 51.6728ZM29.7793 72.5504L45 57.3297V84.5172C45 84.7814 44.9775 84.9814 44.9492 85.1269C44.8163 85.0545 44.6437 84.9413 44.435 84.7674L29.7793 72.5504ZM86.8101 22.3048C87.6391 21.5748 88.9029 21.6551 89.6329 22.4841C95.9918 29.706 99.8511 39.1887 99.8511 49.5678C99.8511 67.7551 88.0104 83.1717 71.6226 88.539C70.5729 88.8828 69.4432 88.3106 69.0994 87.2609C68.7556 86.2112 69.3278 85.0815 70.3775 84.7377C85.1706 79.8927 95.8511 65.9749 95.8511 49.5678C95.8511 40.1986 92.3713 31.6471 86.6308 25.1275C85.9008 24.2985 85.9811 23.0347 86.8101 22.3048ZM78.5882 32.6655C77.8629 31.8323 76.5996 31.7448 75.7665 32.47C74.9333 33.1952 74.8458 34.4585 75.5711 35.2917C78.9352 39.1565 80.9701 44.2024 80.9701 49.7286C80.9701 59.9671 73.9743 68.5766 64.499 71.0285C63.4296 71.3052 62.7871 72.3964 63.0638 73.4658C63.3405 74.5351 64.4317 75.1777 65.501 74.901C76.6981 72.0036 84.9701 61.8346 84.9701 49.7286C84.9701 43.2008 82.5619 37.2306 78.5882 32.6655ZM65.6336 42.7395C66.5875 42.1826 67.8122 42.5044 68.3692 43.4583C69.4063 45.2347 70 47.3018 70 49.5014C70 55.2801 65.9173 60.1007 60.4804 61.2443C59.6784 61.4131 58.8484 61.5014 58 61.5014C56.8954 61.5014 56 60.606 56 59.5014C56 58.3968 56.8954 57.5014 58 57.5014C58.5701 57.5014 59.1241 57.4421 59.657 57.33C63.2805 56.5678 66 53.3499 66 49.5014C66 48.0295 65.6043 46.656 64.9148 45.4751C64.3579 44.5212 64.6797 43.2964 65.6336 42.7395Z\" fill=\"white\"/>\n                </svg>\n                <svg v-else width=\"40px\" height=\"79\" viewBox=\"0 0 100 79\" fill=\"none\" xmlns=\"http://www.w3.org/2000/svg\">\n                    <path fill-rule=\"evenodd\" clip-rule=\"evenodd\" d=\"M43.5951 4.46459L43.5993 4.46113C43.775 4.31509 43.9236 4.21396 44.0428 4.14467C44.065 4.27858 44.0816 4.45432 44.0816 4.67838V73.5313C44.0816 73.7554 44.0649 73.9311 44.0427 74.0649C43.9226 73.9951 43.7727 73.893 43.5951 73.7451L17.9745 52.3878C17.615 52.0881 17.1619 51.924 16.6939 51.924H4.93821C4.42223 51.924 4 51.5018 4 50.9852V27.475C4 26.9568 4.42122 26.5363 4.93821 26.5363H16.6939C17.1658 26.5363 17.6225 26.3694 17.9833 26.0651L43.5951 4.46459ZM48.0816 4.67838C48.0816 3.06732 47.5815 1.14222 45.8201 0.32499C44.0653 -0.489182 42.2711 0.361213 41.0345 1.39157L15.9631 22.5363H4.93821C2.21261 22.5363 0 24.7472 0 27.475V50.9852C0 53.7066 2.20873 55.924 4.93821 55.924H15.9696L41.0345 76.8181C42.2724 77.8496 44.0673 78.6986 45.8218 77.8829C47.5813 77.065 48.0816 75.1413 48.0816 73.5313V4.67838ZM72.1866 1.08479C71.137 0.740628 70.0071 1.31249 69.663 2.36207C69.3188 3.41165 69.8907 4.54151 70.9403 4.88567C85.409 9.63002 95.8541 23.2454 95.8541 39.2952C95.8541 55.3493 85.4034 68.9677 70.9285 73.7085C69.8788 74.0523 69.3066 75.182 69.6504 76.2317C69.9942 77.2814 71.1238 77.8537 72.1735 77.5099C88.2431 72.2467 99.8541 57.1295 99.8541 39.2952C99.8541 21.4657 88.2494 6.35184 72.1866 1.08479ZM63.7718 16.1956C64.0501 15.1267 65.1423 14.4857 66.2112 14.764C77.1786 17.6196 85.2768 27.5879 85.2768 39.4527C85.2768 51.3307 77.1606 61.3081 66.1745 64.1509C65.1051 64.4276 64.014 63.7851 63.7372 62.7157C63.4605 61.6464 64.1031 60.5552 65.1724 60.2785C74.4368 57.8812 81.2768 49.4632 81.2768 39.4527C81.2768 29.4534 74.452 21.043 65.2033 18.635C64.1344 18.3567 63.4935 17.2645 63.7718 16.1956ZM58.8163 27.4342C57.7118 27.4342 56.8163 28.3296 56.8163 29.4342C56.8163 30.5388 57.7118 31.4342 58.8163 31.4342C59.3164 31.4342 59.8036 31.481 60.2745 31.57C63.8831 32.2517 66.6122 35.4243 66.6122 39.2301C66.6122 42.9804 63.9622 46.1163 60.4311 46.859C59.9118 46.9682 59.3719 47.026 58.8163 47.026C57.7118 47.026 56.8163 47.9215 56.8163 49.026C56.8163 50.1306 57.7118 51.026 58.8163 51.026C59.6503 51.026 60.4661 50.9392 61.2545 50.7734C66.599 49.6492 70.6122 44.9106 70.6122 39.2301C70.6122 33.4661 66.48 28.6715 61.017 27.6395C60.3026 27.5045 59.5667 27.4342 58.8163 27.4342Z\" fill=\"white\"/>\n                </svg>\n            </button>\n        </slot>\n    </div>\n</template>\n\n<style lang=\"scss\">\n    #CarouselDiagonal {\n        position: relative;\n        display: block;\n        float: left;\n        width: 100%;\n        height: 100%;\n        .screen {\n            position: absolute;\n            top: 0;\n            left: 0;\n            display: block;\n            float: left;\n            width: 100%;\n            height: 100%;\n            overflow: hidden;\n            transition: all 1s;\n            background: #bdc3c7; /* fallback for old browsers */\n            background: -webkit-linear-gradient(to right, #bdc3c7, #2c3e50); /* Chrome 10-25, Safari 5.1-6 */\n            background: linear-gradient(to right, #bdc3c7, #2c3e50); /* W3C, IE 10+/ Edge, Firefox 16+, Chrome 26+, Opera 12+, Safari 7+ */\n            .title {\n                position: absolute;\n                top: 50%;\n                z-index: 6;\n                display: inline-block;\n                color: white;\n                transition: all 2s;\n                transform: translateX(-50%) translateY(-50%);\n                .title1 {\n                    font-size: 27px;\n                    font-weight: 600;\n                    text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n                    float: left;\n                }\n                .title2 {\n                    font-size: 36px;\n                    font-weight: 900;\n                    text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n                    float: left;\n                }\n            }\n        }\n        &.clicked {\n            .title {\n                top:50% !important;\n                left: 50% !important;\n                opacity: 0;\n                transform: translateX(-50%) translateY(-50%) !important;\n            }\n        }\n        .reset {\n            position: absolute;\n            bottom: 5%;\n            left: 5%;\n            z-index: 6;\n            font-size: 18px;\n            color: white;\n            background: none;\n            line-height: 20px;\n            padding: 10px;\n            * { float: left; }\n            span {\n                line-height: 20px;\n                vertical-align: middle;\n                margin-left: 12px;\n            }\n        }\n\n        button.mute {\n            svg {\n                position: absolute;\n                top: 50%;\n                left: 50%;\n                transform: translate(-50%, -50%);\n            }\n        }\n\n        .fade-enter-active, .fade-leave-active {\n            transition: opacity 1s;\n            opacity: 100;\n        }\n        .fade-enter, .fade-leave-to /* .fade-leave-active below version 2.1.8 */ {\n            opacity: 0;\n        }\n        .b-img {\n            width: 100%;\n            height: 100%;\n            background-size: cover;\n            background-position: center center;\n            object-fit: cover;\n        }\n        button, button:focus {\n            border:none;\n            outline: none;\n            background: none;\n            cursor: pointer;\n        }\n\n        .link-button {\n            position: absolute;\n            width: 100%;\n            height: 50%;\n            top: 50%;\n            left: 50%;\n            transform: translate(-50%, -50%);\n            background: none;\n            z-index: 99;\n        }\n\n        video::-webkit-media-controls-panel { display: none!important; -webkit-appearance: none; }\n        video::-webkit-media-controls-play-button { display: none!important; -webkit-appearance: none; }\n        video::-webkit-media-controls-start-playback-button { display: none!important; -webkit-appearance: none; }\n    }\n</style>","#CarouselDiagonal {\n  position: relative;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n}\n#CarouselDiagonal .screen {\n  position: absolute;\n  top: 0;\n  left: 0;\n  display: block;\n  float: left;\n  width: 100%;\n  height: 100%;\n  overflow: hidden;\n  transition: all 1s;\n  background: #bdc3c7;\n  /* fallback for old browsers */\n  background: -webkit-linear-gradient(to right, #bdc3c7, #2c3e50);\n  /* Chrome 10-25, Safari 5.1-6 */\n  background: linear-gradient(to right, #bdc3c7, #2c3e50);\n  /* W3C, IE 10+/ Edge, Firefox 16+, Chrome 26+, Opera 12+, Safari 7+ */\n}\n#CarouselDiagonal .screen .title {\n  position: absolute;\n  top: 50%;\n  z-index: 6;\n  display: inline-block;\n  color: white;\n  transition: all 2s;\n  transform: translateX(-50%) translateY(-50%);\n}\n#CarouselDiagonal .screen .title .title1 {\n  font-size: 27px;\n  font-weight: 600;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n  float: left;\n}\n#CarouselDiagonal .screen .title .title2 {\n  font-size: 36px;\n  font-weight: 900;\n  text-shadow: 0 4px 8px rgba(0, 0, 0, 0.25);\n  float: left;\n}\n#CarouselDiagonal.clicked .title {\n  top: 50% !important;\n  left: 50% !important;\n  opacity: 0;\n  transform: translateX(-50%) translateY(-50%) !important;\n}\n#CarouselDiagonal .reset {\n  position: absolute;\n  bottom: 5%;\n  left: 5%;\n  z-index: 6;\n  font-size: 18px;\n  color: white;\n  background: none;\n  line-height: 20px;\n  padding: 10px;\n}\n#CarouselDiagonal .reset * {\n  float: left;\n}\n#CarouselDiagonal .reset span {\n  line-height: 20px;\n  vertical-align: middle;\n  margin-left: 12px;\n}\n#CarouselDiagonal button.mute svg {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n}\n#CarouselDiagonal .fade-enter-active, #CarouselDiagonal .fade-leave-active {\n  transition: opacity 1s;\n  opacity: 100;\n}\n#CarouselDiagonal .fade-enter, #CarouselDiagonal .fade-leave-to {\n  opacity: 0;\n}\n#CarouselDiagonal .b-img {\n  width: 100%;\n  height: 100%;\n  background-size: cover;\n  background-position: center center;\n  object-fit: cover;\n}\n#CarouselDiagonal button, #CarouselDiagonal button:focus {\n  border: none;\n  outline: none;\n  background: none;\n  cursor: pointer;\n}\n#CarouselDiagonal .link-button {\n  position: absolute;\n  width: 100%;\n  height: 50%;\n  top: 50%;\n  left: 50%;\n  transform: translate(-50%, -50%);\n  background: none;\n  z-index: 99;\n}\n#CarouselDiagonal video::-webkit-media-controls-panel {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-play-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n#CarouselDiagonal video::-webkit-media-controls-start-playback-button {\n  display: none !important;\n  -webkit-appearance: none;\n}\n\n/*# sourceMappingURL=CarouselDiagonal.vue.map */"]}, media: undefined });

  };
  /* scoped */
  var __vue_scope_id__ = undefined;
  /* module identifier */
  var __vue_module_identifier__ = undefined;
  /* functional template */
  var __vue_is_functional_template__ = false;
  /* style inject SSR */
  
  /* style inject shadow dom */
  

  
  var __vue_component__ = /*#__PURE__*/normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    false,
    createInjector,
    undefined,
    undefined
  );

// Import vue component

// Declare install function executed by Vue.use()
function install(Vue) {
    if (install.installed) { return; }
    install.installed = true;
    Vue.component('DiagnoalScreen', __vue_component__);
}

// Create module definition for Vue.use()
var plugin = {
    install: install,
};

// Auto-install when vue is found (eg. in browser via <script> tag)
var GlobalVue = null;
if (typeof window !== 'undefined') {
    GlobalVue = window.Vue;
} else if (typeof global !== 'undefined') {
    GlobalVue = global.Vue;
}
if (GlobalVue) {
    GlobalVue.use(plugin);
}

export default __vue_component__;
export { install };
